@@ -88,7 +88,7 @@ MODEL_CONFIGS = [
     ),
     ModelConfig(
         short_name="MidJourney-PaperCut",
-        config_path="configs/stable-diffusion-v1-inpaint.yaml",
+        config_path="configs/stable-diffusion-v1.yaml",
         weights_url="https://huggingface.co/ShadoWxShinigamI/MidJourney-PaperCut/resolve/main/Mdjrny-pprct_step_7000.ckpt",
         default_image_size=512,
     ),
@@ -100,37 +100,37 @@ MODEL_CONFIGS = [
     ),
     ModelConfig(
         short_name="Protogen-Anime",
-        config_path="configs/stable-diffusion-v1-inpaint.yaml",
+        config_path="configs/stable-diffusion-v1.yaml",
         weights_url="https://civitai.com/api/download/models/4007",
         default_image_size=512,
     ),
     ModelConfig(
         short_name="Protogen-Photo",
-        config_path="configs/stable-diffusion-v1-inpaint.yaml",
+        config_path="configs/stable-diffusion-v1.yaml",
         weights_url="https://civitai.com/api/download/models/4048",
         default_image_size=512,
     ),
     ModelConfig(
         short_name="Protogen-PhotoV2",
-        config_path="configs/stable-diffusion-v1-inpaint.yaml",
+        config_path="configs/stable-diffusion-v1.yaml",
         weights_url="https://civitai.com/api/download/models/4229",
         default_image_size=512,
     ),
     ModelConfig(
         short_name="RPG",
-        config_path="configs/stable-diffusion-v1-inpaint.yaml",
-        weights_url="https://huggingface.co/Anashel/rpg/blob/main/RPG-v2.ckpt",
+        config_path="configs/stable-diffusion-v1.yaml",
+        weights_url="https://huggingface.co/Anashel/rpg/resolve/main/RPG-v2.ckpt",
         default_image_size=512,
     ),
     ModelConfig(
         short_name="SynthwavePunk",
-        config_path="configs/stable-diffusion-v1-inpaint.yaml",
+        config_path="configs/stable-diffusion-v1.yaml",
         weights_url="https://civitai.com/api/download/models/1144",
         default_image_size=512,
     ),
     ModelConfig(
         short_name="ModernDisney",
-        config_path="configs/stable-diffusion-v1-inpaint.yaml",
+        config_path="configs/stable-diffusion-v1.yaml",
         weights_url="https://huggingface.co/nitrosocke/mo-di-diffusion/resolve/main/moDi-v1-pruned.ckpt",
         default_image_size=512,
     ),
@@ -140,6 +140,12 @@ MODEL_CONFIGS = [
         weights_url="https://civitai.com/api/download/models/3002",
         default_image_size=768,
     ),
+    ModelConfig(
+        short_name="DreamLikeHumans",
+        config_path="configs/stable-diffusion-v1.yaml",
+        weights_url="https://huggingface.co/dreamlike-art/dreamlike-photoreal-2.0/resolve/main/dreamlike-photoreal-2.0.ckpt",
+        default_image_size=768,
+    ),
     # ModelConfig(
     #     short_name="SD-2.0-upscale",
     #     config_path="configs/stable-diffusion-v2-upscaling.yaml",
